package com.my.db.android;

import java.io.BufferedReader;
import java.io.DataOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.net.HttpURLConnection;
import java.net.URL;
import java.net.URLConnection;

import org.json.JSONException;
import org.json.JSONObject;

import com.my.db.android.db.Db;

import android.app.Activity;
import android.content.Intent;
import android.os.Bundle;
import android.view.Menu;
import android.view.MenuInflater;
import android.view.MenuItem;
import android.view.View;
import android.widget.Button;
import android.widget.EditText;
import android.widget.TextView;

public class MainActivity extends Activity {
	private EditText input;
	private TextView output;
	private Button buttonClick;

	private static final String SERVLET_URL = "http://10.0.2.2:9090/BackEndJSON/HelloJSON";

	/** Called when the activity is first created. */
	@Override
	public void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.main);

		input = (EditText) findViewById(R.id.EditText01);
		output = (TextView) findViewById(R.id.TextView01);
		buttonClick = (Button) findViewById(R.id.Button01);
		buttonClick.setOnClickListener(new View.OnClickListener() {

			/**
			 * @see android.view.View.OnClickListener#onClick(android.view.View)
			 */
			public void onClick(View v) {
				String result = getResultFromServlet(input.getText().toString());
				if (result != null) {
					display(result);
					Db dB = new Db(getBaseContext());
					dB.addSearchResult(result);
				} else {
					display("Not found");
				}
			}
		});
	}

	@Override
	public boolean onCreateOptionsMenu(Menu menu) {
		MenuInflater inflater = getMenuInflater();
		inflater.inflate(R.menu.menu, menu);
		return true;
	}

	@Override
	public boolean onOptionsItemSelected(MenuItem item) {
		switch (item.getItemId()) {
		case R.id.history:
			displayHistory();
			return true;
		default:
			return super.onOptionsItemSelected(item);

		}
	}

	private void displayHistory() {
		Intent i = new Intent(this, HistoryActivity.class);
		startActivity(i);
	}

	@Override
	protected void onActivityResult(int requestCode, int resultCode, Intent data) {
		super.onActivityResult(requestCode, resultCode, data);
		display("and we are back");
	}

	/**
	 * @param text
	 *            string
	 */
	protected void display(String text) {
		output.setText(text);
	}

	private String getResultFromServlet(String text) {
		String result = "";

		InputStream in = callService(text);
		if (in != null) {
			JSONObject jsonResponse;
			try {
				jsonResponse = new JSONObject(convertStreamToString(in));
				result = jsonResponse.getString("output");
			} catch (JSONException e) {
				result = "Error: JSON Object couldn't be made";
			}
		} else {
			result = "Error: Service not returning result";
		}
		return result;
	}

	/**
	 * @param envelope
	 */
	private InputStream callService(String text) {
		InputStream in = null;

		try {
			URL url = new URL(SERVLET_URL);
			URLConnection conn = url.openConnection();

			HttpURLConnection httpConn = (HttpURLConnection) conn;
			httpConn.setRequestMethod("POST");
			httpConn.setDoInput(true);
			httpConn.setDoOutput(true);
			httpConn.connect();

			DataOutputStream dataStream = new DataOutputStream(conn
					.getOutputStream());

			dataStream.writeBytes(text);
			dataStream.flush();
			dataStream.close();

			int responseCode = httpConn.getResponseCode();
			if (responseCode == HttpURLConnection.HTTP_OK) {
				in = httpConn.getInputStream();
			}
		} catch (Exception ex) {
			display("Error: Not not connect");
		}
		return in;
	}

	private static String convertStreamToString(InputStream is) {
		BufferedReader reader = new BufferedReader(new InputStreamReader(is));
		StringBuilder sb = new StringBuilder();

		String line = null;
		try {
			while ((line = reader.readLine()) != null) {
				sb.append(line + "\n");
			}
		} catch (IOException e) {
		} finally {
			try {
				is.close();
			} catch (IOException e) {
				e.printStackTrace();
			}
		}
		return sb.toString();
	}
}